==> epath-location-1.2.2-sources.jar: com/shitu/location/epathmap/utils/Constants.java <==
package com.shitu.location.epathmap.utils;

import android.content.Context;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;

import com.shitu.location.R;


/**
 * author:lfei
 */

public class Constants {


//    public static final String BUGLY_ID = "9cb0f110ab";
//    public static final String MIXPANEL_PROJECT_TOKEN = "16e21b84e59b6220a5b0e76bd6271317";
//    public static final String MIXPANEL_PROJECT_TOKEN = "7f8df82d4f642a6b148aebe042627ba2";
//    public static final String PARSE_APPLICATION_ID = "srANu2SqvQXWB9ZEfuM8";
//    public static final String PARSE_SERVER_URL = "https://api.ipsmap.com/parse/";
//    public static final String CLOUD_SERVER_URL = "https://cloud.ipsmap.com";
//    public static final String SHARE_URL = "https://a.mlinks.cc/A0h5";
//    public static final String SHARE_URL = "https://a.mlinks.cc/A0h5";
//    public static final String BD_API_Key = "U1nzgA235pPXBDS9MXVhK8I1";
//    public static final String BD_APP_ID = "9839303";
//    public static final String BD_SECRET_KEY = "78986b507e46afdff60afa9ba07b0763";

    public static final String BUGLY_ID = "7f6df1cbae";
    public static final String MIXPANEL_PROJECT_TOKEN = "3d28bdb9e66823eed118bada130a40b3";
    public static final String PARSE_APPLICATION_ID = "DYLaL8JDXJetpkZfp3ba";
    public static final String PARSE_SERVER_URL = "https://api.e-path.cn/parse/";
    public static final String CLOUD_SERVER_URL = "https://cloud.e-path.cn";
    public static final String SHARE_URL = "https://map.e-path.cn/share";
    public static final String BD_API_Key = "8eMSAqDrvtILjnPWZSLer0SD";
    public static final String BD_APP_ID = "10467288";
    public static final String BD_SECRET_KEY = "7159e6acffa07870ae618ca3eb8ed256";
    public static final String SHARE_LOC_TITLE = "你的好友邀请你加入位置共享";
    public static final String MAPBOX_TOKEN = "pk.eyJ1IjoiZHVzdGZveCIsImEiOiJjajdpcDFjaDUwNW81MzN0NnZzY3c4cnFvIn0.lWfwyYyoMlpMBfCX9jwEnw";
    public static final String MAPBOX_STYLE_URL = "mapbox://styles/dustfox/cj7rgfq1jaf0h2roc02b83fis";




    //Error code message

    public  static final  int ERROR_CODE_0 = 0;
    public static final String ERROR_MESSAGE_0 = "蓝牙需要重启";

     public  static final  int ERROR_CODE_1 = 1;
    public static final String ERROR_MESSAGE_1 = "没有读取地图的权限";

     public  static final  int ERROR_CODE_2 = 2;
    public static final String ERROR_MESSAGE_2 = "地图信息不完整";

    public  static final  int ERROR_CODE_3 = 3;
    public static final String ERROR_MESSAGE_3 = "网络异常 加载地图失败";

   public  static final  int ERROR_CODE_4 = 4;
    public static final String ERROR_MESSAGE_4 = "没有找到目的地,请检查id是否正确!";

   public  static final  int ERROR_CODE_5 = 5;
    public static final String ERROR_MESSAGE_5 = "路径规划失败!";

   public  static final  int ERROR_CODE_6 = 6;
    public static final String ERROR_MESSAGE_6 = "定位失败!";

   public  static final  int ERROR_CODE_7 = 7;
    public static final String ERROR_MESSAGE_7 = "正在加载地图!";


   public  static final  int ERROR_CODE_8 = 8;
    public static final String ERROR_MESSAGE_8 = "没有设置目的地列表!";




    public static int getVersionCode(Context context) {
        try {
            String pkName = context.getPackageName();
            int versionCode = context.getPackageManager().getPackageInfo(
                    pkName, 0).versionCode;
            return versionCode;
        } catch (Exception e) {
        }
        return 0;
    }

    public static String getVersionName(Context context) {
        try {
            String pkName = context.getPackageName();
            String versionName = context.getPackageManager().getPackageInfo(
                    pkName, 0).versionName;
            return versionName;
        } catch (Exception e) {
        }
        return "1.0";
    }

    public static String getAppName(Context context) {
        try {
            PackageManager packageManager = context.getPackageManager();
            PackageInfo packageInfo = packageManager.getPackageInfo(
                    context.getPackageName(), 0);
            int labelRes = packageInfo.applicationInfo.labelRes;
            return context.getResources().getString(labelRes);
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
        return context.getString(R.string.ips_location_app_name);
    }

}

==> epath-location-1.2.8-sources.jar: com/shitu/location/epathmap/utils/Constants.java <==
package com.shitu.location.epathmap.utils;

import android.content.Context;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;

import com.shitu.location.R;


/**
 * author:lfei
 */

public class Constants {


//    public static final String BUGLY_ID = "9cb0f110ab";
//    public static final String MIXPANEL_PROJECT_TOKEN = "16e21b84e59b6220a5b0e76bd6271317";
//    public static final String MIXPANEL_PROJECT_TOKEN = "7f8df82d4f642a6b148aebe042627ba2";
//    public static final String PARSE_APPLICATION_ID = "srANu2SqvQXWB9ZEfuM8";
//    public static final String SHARE_URL = "https://a.mlinks.cc/A0h5";
//    public static final String SHARE_URL = "https://a.mlinks.cc/A0h5";
//    public static final String BD_API_Key = "U1nzgA235pPXBDS9MXVhK8I1";
//    public static final String BD_APP_ID = "9839303";
//    public static final String BD_SECRET_KEY = "78986b507e46afdff60afa9ba07b0763";

    public static final String BUGLY_ID = "7f6df1cbae";
    public static final String MIXPANEL_PROJECT_TOKEN = "3d28bdb9e66823eed118bada130a40b3";
    public static final String PARSE_APPLICATION_ID = "DYLaL8JDXJetpkZfp3ba";
    public static final String PARSE_SERVER_URL = "https://api.e-path.cn/parse/";
    public static final String CLOUD_SERVER_URL = "https://cloud.e-path.cn";
    public static final String SHARE_URL = "https://map.e-path.cn/share";
    public static final String BD_API_Key = "8eMSAqDrvtILjnPWZSLer0SD";
    public static final String BD_APP_ID = "10467288";
    public static final String BD_SECRET_KEY = "7159e6acffa07870ae618ca3eb8ed256";
    public static final String SHARE_LOC_TITLE = "你的好友邀请你加入位置共享";
    public static final String MAPBOX_TOKEN = "pk.eyJ1IjoiZHVzdGZveCIsImEiOiJjajdpcDFjaDUwNW81MzN0NnZzY3c4cnFvIn0.lWfwyYyoMlpMBfCX9jwEnw";
    public static final String MAPBOX_STYLE_URL = "mapbox://styles/dustfox/cj7rgfq1jaf0h2roc02b83fis";




    //Error code message

    public  static final  int ERROR_CODE_0 = 0;
    public static final String ERROR_MESSAGE_0 = "蓝牙需要重启";

     public  static final  int ERROR_CODE_1 = 1;
    public static final String ERROR_MESSAGE_1 = "没有读取地图的权限";

     public  static final  int ERROR_CODE_2 = 2;
    public static final String ERROR_MESSAGE_2 = "地图信息不完整";

    public  static final  int ERROR_CODE_3 = 3;
    public static final String ERROR_MESSAGE_3 = "网络异常 加载地图失败";

   public  static final  int ERROR_CODE_4 = 4;
    public static final String ERROR_MESSAGE_4 = "没有找到目的地,请检查id是否正确!";

   public  static final  int ERROR_CODE_5 = 5;
    public static final String ERROR_MESSAGE_5 = "路径规划失败!";

   public  static final  int ERROR_CODE_6 = 6;
    public static final String ERROR_MESSAGE_6 = "定位失败!";

   public  static final  int ERROR_CODE_7 = 7;
    public static final String ERROR_MESSAGE_7 = "正在加载地图!";


   public  static final  int ERROR_CODE_8 = 8;
    public static final String ERROR_MESSAGE_8 = "没有设置目的地列表!";




    public static int getVersionCode(Context context) {
        try {
            String pkName = context.getPackageName();
            int versionCode = context.getPackageManager().getPackageInfo(
                    pkName, 0).versionCode;
            return versionCode;
        } catch (Exception e) {
        }
        return 0;
    }

    public static String getVersionName(Context context) {
        try {
            String pkName = context.getPackageName();
            String versionName = context.getPackageManager().getPackageInfo(
                    pkName, 0).versionName;
            return versionName;
        } catch (Exception e) {
        }
        return "1.0";
    }

    public static String getAppName(Context context) {
        try {
            PackageManager packageManager = context.getPackageManager();
            PackageInfo packageInfo = packageManager.getPackageInfo(
                    context.getPackageName(), 0);
            int labelRes = packageInfo.applicationInfo.labelRes;
            return context.getResources().getString(labelRes);
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
        return context.getString(R.string.ep_location_app_name);
    }

}
